Crate kdump

Crate kdump 

Structs

CLIConfig
This structure controls all the settings that make this program perform differently These represent command line arguments read in by clap

Statics

DARK_RED_COLOR
GREEN_COLOR
LIGHT_RED_COLOR
ORANGE_COLOR
PURPLE_COLOR
VERSION
WHITE_COLOR

Functions

run