Crate kdump
kdump
2.0.4
All Items
Crate Items
Structs
Statics
Functions
Crate
kdump
Structs

CLIConfig
This structure controls all the settings that make this program perform differently These represent command line arguments read in by clap
Statics

DARK_
RED_
COLOR
GREEN_
COLOR
LIGHT_
RED_
COLOR
ORANGE_
COLOR
PURPLE_
COLOR
VERSION
WHITE_
COLOR
Functions

run